# Platform Name Skill

Template for complex Tier 3 skills.

## Structure

```
skill/
├── SKILL.md            # Dispatcher
├── commands/
│   └── skill.md        # Orchestrator
└── references/
    └── topic/
        ├── README.md   # Overview
        ├── api.md      # API Reference
        ├── config.md   # Configuration
        ├── patterns.md # Recipes
        └── gotchas.md  # Critical Errors
```
